@@ -195,7 +195,8 @@ class ES(object):
 	def hello(self): print (requests.es)
 
 	def dump(self, idxname): 
-		''' python -m so dump gzjc  > gzjc.esjson '''
+		''' python -m so dump gzjc  > gzjc.esjson 
+		# {"_index": "gzjc", "_type": "_doc", "_id": "2897-stype", "_source": {"src": 2897, "tag": "simple_snt", "type": "stype"}}'''
 		for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname):
 			del doc["sort"]
 			del doc["_score"]
@@ -241,11 +242,11 @@ class ES(object):
 			"verbnet":	sqlsi(f"select chunk, count(*) cnt from {idxname} where type = 'verbnet' group by chunk")} ,  dic) 
 		print ('[tocos] totally finished:', idxname)
 
-	def load(self, infile, idxname=None, batch=100000, refresh:bool=True): 
+	def load(self, infile, idxname=None, batch=1000000, refresh:bool=True): 
 		''' python3 -m so load gzjc.esjson '''
 		if not idxname : idxname = infile.split('.')[0]
 		print(">>started: " , infile, idxname, flush=True )
-		#if refresh: self.clear(idxname) 
+		if refresh: self.init(idxname) 
 		actions=[]
 		for line in readline(infile): 
 			try:
@@ -264,6 +265,7 @@ if __name__ == '__main__':
 	fire.Fire(ES)
 
 '''
+{"_index": "gzjc", "_type": "_doc", "_id": "2897-stype", "_source": {"src": 2897, "tag": "simple_snt", "type": "stype"}}
 ubuntu@es-corpusly-com-105-249:/data/cikuu/pypi/so$ python __main__.py ssi  --query "select pos, lem, count(*) cnt from gzjc where type = 'tok' and lem rlike '[a-z]+' group by pos, lem" > gzjc.poslemcnt
 
 	def meta(self, idxname):
