@@ -48,17 +48,31 @@ def doc_meta(text:str='She is happy.'):
 	except Exception as e:
 		print("ex:", e) 
 
+@app.post('/spacy/desc', tags=["spacy"])
+def doc_desc(dic:dict = {"Person=1":"第一人称","Person=3":"第三人称","Number=Sing":"单数", "AUX":"助动词", "VERB":"动词", "NOUN":"名词", "ADJ":"形容词", "ADV":"副词", "PRON":"代词","dobj":"宾语", 'nsubj':'主语','ROOT':"谓语", "acomp":"表语", "Tense=Pres":"现在时", "Tense=Past":"过去时"}
+			, text:str='She is happy.', debug:bool=True): 
+	''' 句子成分描述, 2022.7.10 '''
+	doc		= spacy.nlp(text) #t.morph.to_json():  'Case=Nom|Number=Sing|Person=1|PronType=Prs'
+	predi	= [ t.i for t in doc if t.dep_ == 'ROOT'][0]
+	lat = { t.i: [ f"单词<span class='{t.pos_} {t.tag_}'>{t.text}</span>是 {dic[t.pos_]}"] if t.pos_ in dic else []  for t in doc  } 
+	[ lat[t.i].append( dic[t.dep_] if t.dep_ == 'ROOT' else f"单词<span class='{t.head.pos_} {t.head.tag_}'>{t.head.text}</span>的{dic[t.dep_]}" )  for t in doc if t.dep_ in dic and t.head.i == predi ] # only show the first level, the direct child of pred 
+	[ lat[t.i].append( dic[pair])  for t in doc for pair in t.morph if pair in dic ] # Person=1
+	res =  {"result": ["，".join(v) for v in lat.values() if v]}
+	if debug: res['tok'] = { t.i: (t.text, t.pos_, t.tag_, t.dep_, t.head.i, t.morph.to_json()) for t in doc}
+	return res
+
 @app.get('/spacy/highlight', tags=["spacy"])
-def doc_highlight(text:str='The quick fox jumped over the lazy dog.'): #, pos:str='ADJ'
+def doc_highlight(text:str='And the quick fox hit the lazy dog.', as_html:bool=False): #, pos:str='ADJ'
 	''' return html, with pos highlighted ''' 
 	doc = spacy.nlp(text) 
-	color = {'ROOT': 'red'}
+	color = {'ROOT': 'red', 'dobj': 'gray', 'nsubj':'darkgray', 'cc':'orange'}
 	dic = { t.i:  f"<span class='{t.pos_}' style='color:{color.get(t.dep_, 'black')}'>{t.text_with_ws}</span>" for t in doc }
 	for sp in doc.noun_chunks :
 		if sp.end - sp.start > 1 : 
 			dic[sp.start] = "<u>" + dic[sp.start]
 			dic[sp.end-1] = dic[sp.end-1] + "</u>"
-	return [{"html": "<h1>"  + "".join([ v for v in dic.values()]) + "</h1>" }]
+	html = "<h1>"  + "".join([ v for v in dic.values()]) + "</h1>"
+	return HTMLResponse(content=html) if as_html else [{"html": html }]
 
 @app.get('/spacy/toks', tags=["spacy"])
 def spacy_toks(text:str='The boy is happy. The quick fox jumped over the lazy dog.',chunks:bool=False, sino:str='sino', native:str='dic'): 
@@ -113,4 +127,4 @@ def nlp_ecdic(snt:str="The quick fox jumped over the lazy dog."):
 
 if __name__ == "__main__":  #uvicorn.run(app, host='0.0.0.0', port=19200)
 	#print (spacy_tok(morph=True))	
-	print ( nlp_ecdic()) 
\ No newline at end of file
+	print ( doc_desc()) 
\ No newline at end of file
